% script to read variable values (levels and marginals) from GDX
% the GAMS variables are 2-D: x(I,J) and y(I,K)
% the results are returned as 2-D matrices with the expected size

gdxName = 'solData';

% first get the UELs for each set. Since these are base sets, we just want
% the UELs and don't care about form='sparse' or 'full', and we use
% compress='true' to filter out UELs not in each set
sI = struct('name','I', 'compress','true');
oI = rgdx(gdxName, sI);
sJ = struct('name','J', 'compress','true');
oJ = rgdx(gdxName, sJ);
sK = struct('name','K', 'compress','true');
oK = rgdx(gdxName, sK);

% with the UELS for I, J, and K we can create useful filters
% so the dense/full matrices have the expected size
sXL = struct('name','x', 'form','full');
sXL.uels{1} = oI.uels{1};  sXL.uels{2} = oJ.uels{1};
oXL = rgdx(gdxName, sXL);
XL = oXL.val
sXM = sXL;  sXM.field = 'm';
oXM = rgdx(gdxName, sXM);
XM = oXM.val

sYL = struct('name','y', 'form','full');
sYL.uels{1} = oI.uels{1};  sYL.uels{2} = oK.uels{1};
oYL = rgdx(gdxName, sYL);
YL = oYL.val
sYM = sYL;  sYM.field = 'm';
oYM = rgdx(gdxName, sYM);
YM = oYM.val
